@@ -320,7 +320,7 @@ def create_filter_process(cmd, stream, stream_close, inbound=True):
             proc = popen_with_error_handling(cmd, stdin=subprocess.PIPE, stdout=filter_stream,
                                              log_prefix='filter-process: ', env=env)
         if not proc:
-            raise Error('filter %s: process creation failed' % (cmd, ))
+            raise Error(f'filter {cmd}: process creation failed')
         stream = proc.stdout if inbound else proc.stdin
         # inbound: do not close the pipe (this is the task of the filter process [== writer])
         # outbound: close the pipe, otherwise the filter process would not notice when we are done.
@@ -329,6 +329,15 @@ def create_filter_process(cmd, stream, stream_close, inbound=True):
     try:
         yield stream
 
+    except Exception:
+        # something went wrong with processing the stream by borg
+        logger.debug('Exception, killing the filter...')
+        if cmd:
+            proc.kill()
+        borg_succeeded = False
+        raise
+    else:
+        borg_succeeded = True
     finally:
         if stream_close:
             stream.close()
@@ -339,5 +348,6 @@ def create_filter_process(cmd, stream, stream_close, inbound=True):
             logger.debug('filter cmd exited with code %d', rc)
             if filter_stream_close:
                 filter_stream.close()
-            if rc:
+            if borg_succeeded and rc:
+                # if borg did not succeed, we know that we killed the filter process
                 raise Error('filter %s failed, rc=%d' % (cmd, rc))
